==> fastwechat-1.1.1-sources.jar: net/oschina/suyeer/fastwechat/bean/fwpay/FwPrepayBean.java <==
package net.oschina.suyeer.fastwechat.bean.fwpay;

import net.oschina.suyeer.basic.util.BasicUtil;
import net.oschina.suyeer.fastwechat.util.ConstUtil;

/**
 * Created by jun on 2017/2/9.
 */
public class FwPrepayBean {
    private String appid;
    private String openid;
    private String mch_id;
    private String nonce_str;
    private String body;
    private String out_trade_no;
    private String total_fee;
    private String spbill_create_ip;
    private String trade_type;
    private String notify_url;

    public FwPrepayBean() {
        appid = ConstUtil.APP_ID;
        mch_id = ConstUtil.MCH_ID;
        nonce_str = BasicUtil.getNonceStr();
        out_trade_no = "";
        openid = "";
        body = "";
        total_fee = "";
        spbill_create_ip = "";
        trade_type = "";
        notify_url = "";

    }

    public void setOpenid(String openid) {
        this.openid = openid;
    }

    public void setBody(String body) {
        this.body = body;
    }

    public void setOut_trade_no(String out_trade_no) {
        this.out_trade_no = out_trade_no;
    }

    public void setTotal_fee(String total_fee) {
        this.total_fee = total_fee;
    }

    public void setSpbill_create_ip(String spbill_create_ip) {
        this.spbill_create_ip = spbill_create_ip;
    }

    public void setTrade_type(String trade_type) {
        this.trade_type = trade_type;
    }

    public void setNotify_url(String notify_url) {
        this.notify_url = notify_url;
    }

}

==> fastwechat-1.1.14-sources.jar: net/oschina/suyeer/fastwechat/bean/fwpay/FwPrepayBean.java <==
package net.oschina.suyeer.fastwechat.bean.fwpay;

import net.oschina.suyeer.basic.util.BasicUtil;
import net.oschina.suyeer.fastwechat.util.ConstUtil;
import net.oschina.suyeer.fastwechat.util.FwPayUtil;

/**
 * Created by jun on 2017/2/9.
 */
public class FwPrepayBean {
    private String appid;
    private String openid;
    private String mch_id;
    private String nonce_str;
    private String body;
    private String out_trade_no;
    private String total_fee;
    private String spbill_create_ip;
    private String trade_type;
    private String notify_url;

    public FwPrepayBean() {
        appid = ConstUtil.APP_ID;
        mch_id = ConstUtil.MCH_ID;
        nonce_str = BasicUtil.getNonceStr();
        out_trade_no = FwPayUtil.getOrderNumber(ConstUtil.STRING_EMPTY);
        openid = "";
        body = "";
        total_fee = "";
        spbill_create_ip = "";
        trade_type = "";
        notify_url = "";
    }

    public void setOpenid(String openid) {
        this.openid = openid;
    }

    public void setBody(String body) {
        this.body = body;
    }

    public void setOut_trade_no(String out_trade_no) {
        this.out_trade_no = out_trade_no;
    }

    public void setTotal_fee(String total_fee) {
        this.total_fee = total_fee;
    }

    public void setSpbill_create_ip(String spbill_create_ip) {
        this.spbill_create_ip = spbill_create_ip;
    }

    public void setTrade_type(String trade_type) {
        this.trade_type = trade_type;
    }

    public void setNotify_url(String notify_url) {
        this.notify_url = notify_url;
    }

    public String getAppid() {
        return appid;
    }

    public String getOpenid() {
        return openid;
    }

    public String getMch_id() {
        return mch_id;
    }

    public String getNonce_str() {
        return nonce_str;
    }

    public String getBody() {
        return body;
    }

    public String getOut_trade_no() {
        return out_trade_no;
    }

    public String getTotal_fee() {
        return total_fee;
    }

    public String getSpbill_create_ip() {
        return spbill_create_ip;
    }

    public String getTrade_type() {
        return trade_type;
    }

    public String getNotify_url() {
        return notify_url;
    }
}
